summaryrefslogtreecommitdiff
path: root/build.zig
diff options
context:
space:
mode:
Diffstat (limited to 'build.zig')
-rw-r--r--build.zig16
1 files changed, 8 insertions, 8 deletions
diff --git a/build.zig b/build.zig
index 795d8e2..c5d662f 100644
--- a/build.zig
+++ b/build.zig
@@ -156,7 +156,7 @@ pub fn build(b: *std.Build) void {
const is_linux = target.result.os.tag == .linux;
const want_9proc = b.option(bool, "9proc", "Build the 9proc library module and demo (default: target is Linux)") orelse is_linux;
const want_9ns = b.option(bool, "9ns", "Build the 9ns FUSE mount CLI (default: target is Linux; Linux only)") orelse is_linux;
- const want_9harness = b.option(bool, "9harness", "Build the harness fs daemon (default: target is Linux; Linux only)") orelse is_linux;
+ const want_9agents = b.option(bool, "9agents", "Build the coding-agents fs daemon (default: target is Linux; Linux only)") orelse is_linux;
if (want_9ns and !is_linux) {
std.debug.print("error: -D9ns=true needs a Linux target (got {s})\n", .{@tagName(target.result.os.tag)});
std.process.exit(1);
@@ -207,21 +207,21 @@ pub fn build(b: *std.Build) void {
programs_itest.dependOn(p.itest_step);
}
// The harness fs daemon: a read-only 9P view of every harness's
// state, posted by default as `harness` (Linux only: it posts into
// $XDG_RUNTIME_DIR/9p through cloud9.post).
- if (want_9harness and !is_linux) {
- std.debug.print("error: -D9harness=true needs a Linux target (got {s})\n", .{@tagName(target.result.os.tag)});
+ if (want_9agents and !is_linux) {
+ std.debug.print("error: -D9agents=true needs a Linux target (got {s})\n", .{@tagName(target.result.os.tag)});
std.process.exit(1);
}
- const harness_build = @import("9harness/build.zig");
- const harness: ?harness_build.Artifacts = if (want_9harness) harness_build.add(b, .{
+ const agents_build = @import("9agents/build.zig");
+ const agents: ?agents_build.Artifacts = if (want_9agents) agents_build.add(b, .{
.target = target,
.optimize = optimize,
.cloud9 = module,
.ns = if (ns) |p| p.exe else null,
}) else null;
- if (harness) |p| {
+ if (agents) |p| {
programs_test.dependOn(p.test_step);
programs_itest.dependOn(p.itest_step);
}
@@ -207,21 +207,21 @@ pub fn build(b: *std.Build) void {
programs_itest.dependOn(p.itest_step);
}
- // The harness fs daemon: a read-only 9P view of every harness's
- // state, posted by default as `harness` (Linux only: it posts into
+ // The coding-agents fs daemon: a read-only 9P view of every harness's
+ // state, posted by default as `agents` (Linux only: it posts into
// $XDG_RUNTIME_DIR/9p through cloud9.post).